@@ -30,6 +30,7 @@ import contextlib
 import stat
 
 import pytest
+from more_itertools import ilen
 
 import path
 from path import Path
@@ -78,6 +79,12 @@ class TestBasics:
             d = Path('D:\\')
             assert d.relpathto(boz) == boz
 
+    def test_construction_without_args(self):
+        """
+        Path class will construct a path to current directory when called with no arguments.
+        """
+        assert Path() == '.'
+
     def test_construction_from_none(self):
         """ """
         with pytest.raises(TypeError):
@@ -124,9 +131,9 @@ class TestBasics:
         assert f.name == 'xyzzy.py'
         assert f.parent.name == os_choose(nt='Lib', posix='lib')
 
-        # .ext
-        assert f.ext == '.py'
-        assert f.parent.ext == ''
+        # .suffix
+        assert f.suffix == '.py'
+        assert f.parent.suffix == ''
 
         # .drive
         assert f.drive == os_choose(nt='C:', posix='')
@@ -293,10 +300,10 @@ class TestBasics:
         (dir / 'file').touch()
         (dir / 'sub').mkdir()
         dir.removedirs_p()
-        assert dir.isdir()
-        assert (dir / 'file').isfile()
+        assert dir.is_dir()
+        assert (dir / 'file').is_file()
         # TODO: shouldn't sub get removed?
-        # assert not (dir / 'sub').isdir()
+        # assert not (dir / 'sub').is_dir()
 
 
 class TestReadWriteText:
@@ -353,7 +360,7 @@ class TestLinks:
         with root:
             file = (Path('dir').mkdir() / 'file').touch()
             file.symlink()
-            assert Path('file').isfile()
+            assert Path('file').is_file()
 
     def test_readlinkabs_passthrough(self, tmpdir):
         link = Path(tmpdir) / 'link'
@@ -376,7 +383,7 @@ class TestSymbolicLinksWalk:
         assert len(list(root.walk())) == 4
 
         skip_links = path.Traversal(
-            lambda item: item.isdir() and not item.islink(),
+            lambda item: item.is_dir() and not item.islink(),
         )
         assert len(list(skip_links(root.walk()))) == 3
 
@@ -424,7 +431,7 @@ def test_chroot(monkeypatch):
     results = []
     monkeypatch.setattr(os, 'chroot', results.append)
     Path().chroot()
-    assert results == ['']
+    assert results == [Path()]
 
 
 @pytest.mark.skipif("not hasattr(Path, 'startfile')")
@@ -432,7 +439,7 @@ def test_startfile(monkeypatch):
     results = []
     monkeypatch.setattr(os, 'startfile', results.append)
     Path().startfile()
-    assert results == ['']
+    assert results == [Path()]
 
 
 class TestScratchDir:
@@ -467,7 +474,7 @@ class TestScratchDir:
         t1 = time.time() + threshold
 
         assert f.exists()
-        assert f.isfile()
+        assert f.is_file()
         assert f.size == 0
         assert t0 <= f.mtime <= t1
         if hasattr(os.path, 'getctime'):
@@ -486,7 +493,7 @@ class TestScratchDir:
         assert t0 <= t1 < t2 <= t3  # sanity check
 
         assert f.exists()
-        assert f.isfile()
+        assert f.is_file()
         assert f.size == 10
         assert t2 <= f.mtime <= t3
         if hasattr(os.path, 'getctime'):
@@ -506,7 +513,7 @@ class TestScratchDir:
 
     def test_listing(self, tmpdir):
         d = Path(tmpdir)
-        assert d.listdir() == []
+        assert list(d.iterdir()) == []
 
         f = 'testfile.txt'
         af = d / f
@@ -515,7 +522,7 @@ class TestScratchDir:
         try:
             assert af.exists()
 
-            assert d.listdir() == [af]
+            assert list(d.iterdir()) == [af]
 
             # .glob()
             assert d.glob('testfile.txt') == [af]
@@ -539,7 +546,7 @@ class TestScratchDir:
             with open(f, 'w', encoding='utf-8') as fobj:
                 fobj.write('some text\n')
         try:
-            files2 = d.listdir()
+            files2 = list(d.iterdir())
             files.sort()
             files2.sort()
             assert files == files2
@@ -550,7 +557,7 @@ class TestScratchDir:
 
     @pytest.fixture
     def bytes_filename(self, tmpdir):
-        name = br'r\xe9\xf1emi'
+        name = rb'r\xe9\xf1emi'
         base = str(tmpdir).encode('ascii')
         try:
             with open(os.path.join(base, name), 'wb'):
@@ -559,17 +566,17 @@ class TestScratchDir:
             raise pytest.skip(f"Invalid encodings disallowed {exc}")
         return name
 
-    def test_listdir_other_encoding(self, tmpdir, bytes_filename):  # pragma: nocover
+    def test_iterdir_other_encoding(self, tmpdir, bytes_filename):  # pragma: nocover
         """
         Some filesystems allow non-character sequences in path names.
-        ``.listdir`` should still function in this case.
+        ``.iterdir`` should still function in this case.
         See issue #61 for details.
         """
         # first demonstrate that os.listdir works
         assert os.listdir(str(tmpdir).encode('ascii'))
 
         # now try with path
-        results = Path(tmpdir).listdir()
+        results = Path(tmpdir).iterdir()
         (res,) = results
         assert isinstance(res, Path)
         assert len(res.basename()) == len(bytes_filename)
@@ -586,7 +593,7 @@ class TestScratchDir:
             boz = foo / 'bar' / 'baz' / 'boz'
             boz.makedirs()
             try:
-                assert boz.isdir()
+                assert boz.is_dir()
             finally:
                 boz.removedirs()
             assert not foo.exists()
@@ -595,7 +602,7 @@ class TestScratchDir:
             foo.mkdir(0o750)
             boz.makedirs(0o700)
             try:
-                assert boz.isdir()
+                assert boz.is_dir()
             finally:
                 boz.removedirs()
             assert not foo.exists()
@@ -641,13 +648,13 @@ class TestScratchDir:
 
         # Test simple file copying.
         testFile.copyfile(testCopy)
-        assert testCopy.isfile()
+        assert testCopy.is_file()
         assert testFile.bytes() == testCopy.bytes()
 
         # Test copying into a directory.
         testCopy2 = testA / testFile.name
         testFile.copy(testA)
-        assert testCopy2.isfile()
+        assert testCopy2.is_file()
         assert testFile.bytes() == testCopy2.bytes()
 
         # Make a link for the next test to use.
@@ -655,9 +662,9 @@ class TestScratchDir:
 
         # Test copying directory tree.
         testA.copytree(testC)
-        assert testC.isdir()
+        assert testC.is_dir()
         self.assertSetsEqual(
-            testC.listdir(),
+            testC.iterdir(),
             [testC / testCopy.name, testC / testFile.name, testCopyOfLink],
         )
         assert not testCopyOfLink.islink()
@@ -668,9 +675,9 @@ class TestScratchDir:
 
         # Copy again, preserving symlinks.
         testA.copytree(testC, True)
-        assert testC.isdir()
+        assert testC.is_dir()
         self.assertSetsEqual(
-            testC.listdir(),
+            testC.iterdir(),
             [testC / testCopy.name, testC / testFile.name, testCopyOfLink],
         )
         if hasattr(os, 'symlink'):
@@ -680,7 +687,7 @@ class TestScratchDir:
         # Clean up.
         testDir.rmtree()
         assert not testDir.exists()
-        self.assertList(d.listdir(), [])
+        self.assertList(d.iterdir(), [])
 
     def assertList(self, listing, expected):
         assert sorted(listing) == sorted(expected)
@@ -691,12 +698,12 @@ class TestScratchDir:
         dirs = [d, d / 'xdir', d / 'xdir.tmp', d / 'xdir.tmp' / 'xsubdir']
 
         for e in dirs:
-            if not e.isdir():
+            if not e.is_dir():
                 e.makedirs()
 
             for name in names:
                 (e / name).touch()
-        self.assertList(d.listdir('*.tmp'), [d / 'x.tmp', d / 'xdir.tmp'])
+        self.assertList(d.iterdir('*.tmp'), [d / 'x.tmp', d / 'xdir.tmp'])
         self.assertList(d.files('*.tmp'), [d / 'x.tmp'])
         self.assertList(d.dirs('*.tmp'), [d / 'xdir.tmp'])
         self.assertList(
@@ -906,27 +913,27 @@ class TestMergeTree:
 
     def check_link(self):
         target = Path(self.subdir_b / self.test_link.name)
-        check = target.islink if hasattr(os, 'symlink') else target.isfile
+        check = target.islink if hasattr(os, 'symlink') else target.is_file
         assert check()
 
     def test_with_nonexisting_dst_kwargs(self):
         self.subdir_a.merge_tree(self.subdir_b, symlinks=True)
-        assert self.subdir_b.isdir()
+        assert self.subdir_b.is_dir()
         expected = {
             self.subdir_b / self.test_file.name,
             self.subdir_b / self.test_link.name,
         }
-        assert set(self.subdir_b.listdir()) == expected
+        assert set(self.subdir_b.iterdir()) == expected
         self.check_link()
 
     def test_with_nonexisting_dst_args(self):
         self.subdir_a.merge_tree(self.subdir_b, True)
-        assert self.subdir_b.isdir()
+        assert self.subdir_b.is_dir()
         expected = {
             self.subdir_b / self.test_file.name,
             self.subdir_b / self.test_link.name,
         }
-        assert set(self.subdir_b.listdir()) == expected
+        assert set(self.subdir_b.iterdir()) == expected
         self.check_link()
 
     def test_with_existing_dst(self):
@@ -941,13 +948,13 @@ class TestMergeTree:
 
         self.subdir_a.merge_tree(self.subdir_b, True)
 
-        assert self.subdir_b.isdir()
+        assert self.subdir_b.is_dir()
         expected = {
             self.subdir_b / self.test_file.name,
             self.subdir_b / self.test_link.name,
             self.subdir_b / test_new.name,
         }
-        assert set(self.subdir_b.listdir()) == expected
+        assert set(self.subdir_b.iterdir()) == expected
         self.check_link()
         assert len(Path(self.subdir_b / self.test_file.name).bytes()) == 5000
 
@@ -958,8 +965,8 @@ class TestMergeTree:
         ignore = shutil.ignore_patterns('testlink*')
         self.subdir_a.merge_tree(self.subdir_b, ignore=ignore)
 
-        assert self.subdir_b.isdir()
-        assert self.subdir_b.listdir() == [self.subdir_b / self.test_file.name]
+        assert self.subdir_b.is_dir()
+        assert list(self.subdir_b.iterdir()) == [self.subdir_b / self.test_file.name]
 
     def test_only_newer(self):
         """
@@ -977,7 +984,11 @@ class TestMergeTree:
     def test_nested(self):
         self.subdir_a.joinpath('subsub').mkdir()
         self.subdir_a.merge_tree(self.subdir_b)
-        assert self.subdir_b.joinpath('subsub').isdir()
+        assert self.subdir_b.joinpath('subsub').is_dir()
+
+    def test_listdir(self):
+        with pytest.deprecated_call():
+            Path().listdir()
 
 
 class TestChdir:
@@ -1029,7 +1040,7 @@ class TestTempDir:
         d = TempDir()
         assert isinstance(d, path.Path)
         assert d.exists()
-        assert d.isdir()
+        assert d.is_dir()
         d.rmdir()
         assert not d.exists()
 
@@ -1063,8 +1074,8 @@ class TestTempDir:
         """
 
         with TempDir() as d:
-            assert d.isdir()
-        assert not d.isdir()
+            assert d.is_dir()
+        assert not d.is_dir()
 
     def test_cleaned_up_on_interrupt(self):
         with contextlib.suppress(KeyboardInterrupt):
@@ -1105,22 +1116,22 @@ class TestPatternMatching:
         assert p.fnmatch('foobar', normcase=normcase)
         assert p.fnmatch('FOO[ABC]AR', normcase=normcase)
 
-    def test_listdir_simple(self):
+    def test_iterdir_simple(self):
         p = Path('.')
-        assert len(p.listdir()) == len(os.listdir('.'))
+        assert ilen(p.iterdir()) == len(os.listdir('.'))
 
-    def test_listdir_empty_pattern(self):
+    def test_iterdir_empty_pattern(self):
         p = Path('.')
-        assert p.listdir('') == []
+        assert list(p.iterdir('')) == []
 
-    def test_listdir_patterns(self, tmpdir):
+    def test_iterdir_patterns(self, tmpdir):
         p = Path(tmpdir)
         (p / 'sub').mkdir()
         (p / 'File').touch()
-        assert p.listdir('s*') == [p / 'sub']
-        assert len(p.listdir('*')) == 2
+        assert list(p.iterdir('s*')) == [p / 'sub']
+        assert ilen(p.iterdir('*')) == 2
 
-    def test_listdir_custom_module(self, tmpdir):
+    def test_iterdir_custom_module(self, tmpdir):
         """
         Listdir patterns should honor the case sensitivity of the path module
         used by that Path class.
@@ -1129,14 +1140,14 @@ class TestPatternMatching:
         p = always_unix(tmpdir)
         (p / 'sub').mkdir()
         (p / 'File').touch()
-        assert p.listdir('S*') == []
+        assert list(p.iterdir('S*')) == []
 
         always_win = Path.using_module(ntpath)
         p = always_win(tmpdir)
-        assert p.listdir('S*') == [p / 'sub']
-        assert p.listdir('f*') == [p / 'File']
+        assert list(p.iterdir('S*')) == [p / 'sub']
+        assert list(p.iterdir('f*')) == [p / 'File']
 
-    def test_listdir_case_insensitive(self, tmpdir):
+    def test_iterdir_case_insensitive(self, tmpdir):
         """
         Listdir patterns should honor the case sensitivity of the path module
         used by that Path class.
@@ -1144,8 +1155,8 @@ class TestPatternMatching:
         p = Path(tmpdir)
         (p / 'sub').mkdir()
         (p / 'File').touch()
-        assert p.listdir(matchers.CaseInsensitive('S*')) == [p / 'sub']
-        assert p.listdir(matchers.CaseInsensitive('f*')) == [p / 'File']
+        assert list(p.iterdir(matchers.CaseInsensitive('S*'))) == [p / 'sub']
+        assert list(p.iterdir(matchers.CaseInsensitive('f*'))) == [p / 'File']
         assert p.files(matchers.CaseInsensitive('S*')) == []
         assert p.dirs(matchers.CaseInsensitive('f*')) == []
 
